@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-bookmarks-tray-extension.c,v 1.14.2.2 2005/03/19 19:45:32 chpe Exp $
+ *  $Id: ephy-bookmarks-tray-extension.c,v 1.17 2005/04/19 11:30:16 chpe Exp $
  */
 
 #include "config.h"
@@ -424,7 +424,7 @@ open_in_changed_cb (GtkAction *action,
 			      types[extension->priv->open_in].text);
 }
 
-static GtkActionEntry action_entries [] =
+static const GtkActionEntry action_entries [] =
 {
 	{ "Bookmarks", NULL, "" },
 	{ "Context", NULL, "" },
@@ -433,7 +433,7 @@ static GtkActionEntry action_entries [] =
           G_CALLBACK (edit_bookmarks_cb) },
 };
 
-static GtkRadioActionEntry radio_entries [] =
+static const GtkRadioActionEntry radio_entries [] =
 {
 	{ "OpenInCurrent", NULL, N_("Open in _Current Tab"), NULL,
 	  N_("Open bookmarks in the current tab of the active window"),
